@@ -1,3 +1,4 @@
+import uuid
 from typing import Dict, List, Union
 
 JSONPrimitive = Union[str, int, None, float]
@@ -6,3 +7,5 @@ JSONObject = Dict[str, JSONValue]
 
 ProcessVariable = Dict[str, JSONPrimitive]  # {"type": "Integer", "value": 42}
 ProcessVariables = Dict[str, ProcessVariable]
+
+CamundaId = Union[str, uuid.UUID]
